pub enum Command {
Toggle(Component),
On(Component),
Off(Component),
}Expand description
Commands that can be dispatched securely over the air. Will be more expandable in future versions.
Variants
Toggle(Component)
Invert the current power state of the target component.
On(Component)
Explicitly power on the target component.
Off(Component)
Explicitly power off the target component.